#!/usr/bin/env python

# sugar-lint: disable

import os
import sys
from os.path import exists, lexists, islink

sys.path.insert(0, '..')
from tests import Test, main
from tests.providers import dnsmasq
from libmace.files import Transaction
from libmace import files


class ProviderDnsmasqTest(Test):

    def test_ensure_InEmptyEnv(self):
        provider = dnsmasq.Provider()
        tran = Transaction('.')

        provider.ensure(None, tran)

        assert exists('etc/resolv.conf')
        self.assertEqual(
                ['nameserver 127.0.0.1'],
                file('etc/resolv.conf').readlines())

        assert exists('etc/resolv.conf.dnsmasq')
        self.assertEqual(
                ['nameserver 8.8.8.8\n',
                 'nameserver 8.8.4.4',
                 ],
                file('etc/resolv.conf.dnsmasq').readlines())

    def test_ensure_ExistedResolvConf(self):
        provider = dnsmasq.Provider()
        tran = Transaction('.')
        self.touch(('etc/resolv.conf', [
            'search foo',
            'nameserver bar',
            ]))

        provider.ensure(None, tran)

        assert exists('etc/resolv.conf')
        self.assertEqual(
                ['search foo\n',
                 'nameserver 127.0.0.1',
                 ],
                file('etc/resolv.conf').readlines())

        assert exists('etc/resolv.conf.dnsmasq')
        self.assertEqual(
                ['nameserver bar',
                 ],
                file('etc/resolv.conf.dnsmasq').readlines())

    def test_ensure_AlreadyChanged(self):
        provider = dnsmasq.Provider()
        tran = Transaction('.')

        self.touch(('etc/resolv.conf', [
            'search foo',
            'nameserver bar',
            'nameserver 127.0.0.1',
            ]))
        self.touch(('etc/resolv.conf.dnsmasq', [
            'nameserver fake',
            ]))

        provider.ensure(None, tran)

        assert exists('etc/resolv.conf')
        self.assertEqual(
                ['search foo\n',
                 'nameserver bar\n',
                 'nameserver 127.0.0.1',
                 ],
                file('etc/resolv.conf').readlines())

        assert exists('etc/resolv.conf.dnsmasq')
        self.assertEqual(
                ['nameserver fake',
                 ],
                file('etc/resolv.conf.dnsmasq').readlines())

    def test_footer(self):
        provider = dnsmasq.Provider()
        self.assertEqual(
                ['resolv-file=/etc/resolv.conf.dnsmasq'],
                provider.footer(None, None))


if __name__ == '__main__':
    main()
