#!/usr/bin/env python

# pep8: ignore=E501
# pylint: disable-msg=C0301

import os
import sys
from os.path import exists, lexists, islink

sys.path.insert(0, '..')
from tests import Test, main
from tests.providers import pafm
from libmace.files import Transaction
from libmace import files


class ProviderPafmTest(Test):

    def setUp(self):
        Test.setUp(self)
        files.uid_by_name = hash
        files.gid_by_name = hash

    def test_ensure(self):
        provider = pafm.Provider()

        self.touch(('etc/pafm.conf', [
            '[main]',
            'www_root=/www_root',
            'files_root=/files_root',
            ]))
        assert os.stat('etc/pafm.conf').st_mode & 0777 != 0600

        tran = Transaction('.')
        self.assertRaises(RuntimeError, provider.ensure, None, tran)

        tran.envars['HTTP_USER'] = 'http_user'
        tran.envars['HTTP_GROUP'] = 'http_group'
        provider.ensure(None, tran)

        assert os.stat('etc/pafm.conf').st_mode & 0777 == 0600
        assert ('./etc/pafm.conf', hash('http_user'), hash('http_group')) in self.chown
        assert exists('www_root')
        assert ('./www_root', hash('http_user'), hash('http_group')) in self.chown
        assert os.stat('www_root').st_mode & 0777 == 0755
        assert islink('www_root/index.php')
        self.assertEqual('/usr/share/pafm/pafm.php', os.readlink('www_root/index.php'))
        assert islink('www_root/pafm')
        self.assertEqual('/usr/share/pafm/pafm', os.readlink('www_root/pafm'))

        assert exists('files_root')
        assert ('./files_root', hash('http_user'), hash('http_group')) in self.chown
        assert os.stat('files_root').st_mode & 0777 == 0755

        assert lexists('www_root/files')
        self.assertEqual('/files_root', os.readlink('www_root/files'))


if __name__ == '__main__':
    main()
